#!/bin/bash
set -exo pipefail

function main() {
    {
    upgradeSystem

    mkdir -p /usr/share/man/man1
    apt-get -qqy install openjdk-17-jre-headless leiningen curl
    
    # shadow-cljs
    npm install -g npm
    npm install -g --save-dev shadow-cljs

    # download kubeconform & graalvm
    kubeconform_version="0.6.4"

    curl -SsLo /tmp/kubeconform.tar.gz https://github.com/yannh/kubeconform/releases/download/v${kubeconform_version}/kubeconform-linux-amd64.tar.gz
    curl -SsLo /tmp/CHECKSUMS https://github.com/yannh/kubeconform/releases/download/v${kubeconform_version}/CHECKSUMS

    # checksum kubeconform
    checksum

    # install kubeconform
    tar -C /usr/local/bin -xf /tmp/kubeconform.tar.gz --exclude=LICENSE

    #install pyb
    apt-get -qqy install python3 python3-pip git
    pip3 install pybuilder 'ddadevops>=4.7.0' deprecation dda-python-terraform boto3 pyyaml inflection --break-system-packages

    #check
    lein --help

    cleanupDocker
    } > /dev/null
}

function checksum() {
    checksum_var=$(awk '{print $1}' /tmp/CHECKSUMS|sed -n '2p')
    sha256sum_var=$(sha256sum /tmp/kubeconform.tar.gz|awk '{print $1}')
    
    if [ $checksum_var == $sha256sum_var ]; then
        echo "Kubeconform checksum verification succesful" 
    else
        echo "Failure in kubeconform checksum verification"
        exit 1
    fi
}

source /tmp/install_functions_debian.sh
DEBIAN_FRONTEND=noninteractive DEBCONF_NOWARNINGS=yes main